@@ -1,3 +1,5 @@
+( cd opt/kde/share/doc/HTML/en/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/juk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmix ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/dragonplayer ; rm -rf common )
